//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Description of Csound environment variables.
//
//		Purists take note: I know that the design is not completely sound.
//		I just can't be bothered to introduce new abstract superclasses for
//		jobs and windows, just so that I can have a "clean" inheritance
//		hierarchy.

#ifndef CSENVJOB_H
#define CSENVJOB_H

#include <Message.h>
#include <SupportDefs.h>

#include "CsAbstractJob.h"

class CsoundEnvironmentJob : public CsoundAbstractJob
{
public:
	typedef CsoundAbstractJob inherited;
	
	// Filename specifiers.
	enum {
		kSoundfileDirectory,			// SFDIR
		kSoundSampleDirectory,		// SSDIR
		kSoundAnalysisDirectory,	// SADIR
		
		kNumFilenames
	};
	
	CsoundEnvironmentJob(
		bool assignName = true,
		uint32 numFilenames = kNumFilenames);
	CsoundEnvironmentJob(const CsoundEnvironmentJob &job);
	CsoundEnvironmentJob &operator =(const CsoundEnvironmentJob &job);	
	virtual ~CsoundEnvironmentJob(void);

	virtual CsoundAbstractJob *New(void) const;
	virtual CsoundAbstractJob *Clone(void) const;
	virtual CsoundAbstractJob &Become(const CsoundAbstractJob &job);

	virtual bool operator ==(const CsoundAbstractJob &job) const;

	// Archiving methods.
	CsoundEnvironmentJob(BMessage *pMsg);
	virtual status_t Archive(BMessage *pMsg, bool deep = true) const;
#pragma export on
	static CsoundEnvironmentJob *Instantiate(BMessage *pMsg);
#pragma export reset

	// Check if the job is valid.
	virtual bool IsValid(void) const;
	
	// Return current directory for execution (dummy).
	virtual const char *CurrentDirectory(void) const;
	
	// Construct and return the environment.
	// The returned memory must be explicitly freed.
	char **CopyEnvironment(void) const;

	// Return a name for the class.
	virtual const char *JobClass(void) const;
	
	// Construct a title for a window.
	virtual char *CopyWindowTitle(void) const;

	// Create an instance of the concrete window class.
	virtual CsoundAbstractWindow *CreateWindow(BPoint origin) const;

private:
	// Abused to implement CopyEnvironment().
	virtual char **CopyCommandArguments(const char * = 0) const;
};

inline char **
CsoundEnvironmentJob::CopyEnvironment(void) const
{
	return CopyCommandArguments();
}

#endif // CSENVJOB_H
