//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		A view class for monitoring output to a FILE.

#ifndef CSTRANSCRIPTVIEW_H
#define CSTRANSCRIPTVIEW_H

#include <cstdio>
#include <cstring>

#include <OS.h>
#include <Rect.h>
#include <TextView.h>

class CsoundTranscriptView : public BTextView
{
public:
	typedef BTextView inherited;
	
	CsoundTranscriptView(BRect frame, const char *pName, FILE *pFile,
								 uint32 resizeMask, uint32 flags);
	virtual ~CsoundTranscriptView(void);
	
	// Hook functions.
	virtual void AttachedToWindow(void);
	virtual void DetachedFromWindow(void);
	virtual void FrameResized(float width, float height);
	virtual void Pulse(void);

private:
	CsoundTranscriptView(const CsoundTranscriptView &);
	CsoundTranscriptView &operator =(const CsoundTranscriptView &);
	
	// Monitor functions.
	static int32 MonitorFile(void *pData);
	static void SigHandler(int sig, void *pData, struct vregs *);
	int32 MonitorFile(void);
	void StartMonitor(void);
	void SuspendMonitor(void);
	void StopMonitor(void);

	// Private class for accumulating text.	
	class Buffer
	{
		char *mpBuffer;
		size_t mLength;
		size_t mFree;

		Buffer(const Buffer &);
		Buffer &operator =(const Buffer &);

	public:
		enum { kBufferSize = 1024 };

		Buffer(void);
		~Buffer(void);

		Buffer &operator +=(const char *pChars);
		void Clear(void);
		
		size_t Length(void) const				{ return mLength;		}
		operator char *(void)					{ return mpBuffer;	}
		operator const char *(void) const	{ return mpBuffer;	}
	};

	// Data members.
	BRect mTextRect;
	
	FILE *const mpFile;
	sem_id mMonitorSem;
	thread_id mMonitorThread;
	enum { kRunning, kSuspended, kFinished } mState;
	bool mSignaled;

	Buffer mTextBuffer;
	sem_id mBufferSem;
};

#endif // CSTRANSCRIPTVIEW_H
