//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Abstract window class for Csound.  Serves as a base class for all 
//		the dialog-oriented windows.

#ifndef CSABSTRACTWINDOW_H
#define CSABSTRACTWINDOW_H

#include <Button.h>
#include <CheckBox.h>
#include <Point.h>
#include <RadioButton.h>
#include <TextControl.h>
#include <View.h>
#include <Window.h>

class CsoundAbstractMainWindow;

class CsoundAbstractWindow : public BWindow
{
public:
	typedef BWindow inherited;
	
	CsoundAbstractWindow(BPoint origin, const char *pTitle);
	virtual ~CsoundAbstractWindow(void);

protected:
	// Create resp. return the window's background view.
	void CreateBackgroundView(
		BRect frame, const char *pTitle, rgb_color viewColor);
	BView *BackgroundView(void) const;
	
	// Utilities for dialog layout.  Each CreateControls() method creates
	// a bunch of controls which will send messages to the supplied main
	// window.  The controls are initialized from the main window's job.
	struct ButtonDescriptor {
		BButton *CsoundAbstractWindow::* /*const*/ pButton;
		const char *const pName;
		const char *const pLabel;
		uint32 msgWhat;
		float width, height;	
	};
	void CreateControls(ButtonDescriptor descriptors[],
								uint32 nItems,
								const CsoundAbstractMainWindow &target);

	struct CheckBoxDescriptor {
		BCheckBox *CsoundAbstractWindow::* /*const*/ pCheckBox;
		const char *const pName;
		const char *const pLabel;
		int32 option;
		float width, height;	
	};
	void CreateControls(CheckBoxDescriptor descriptors[],
								uint32 nItems,
								const CsoundAbstractMainWindow &target);

	struct RadioButtonDescriptor {
		BRadioButton *CsoundAbstractWindow::* /*const*/ pRadioButton;
		const char *const pName;
		const char *const pLabel;
		int32 mask, value;
		float width, height;	
	};
	void CreateControls(RadioButtonDescriptor descriptors[],
								uint32 nItems,
								const CsoundAbstractMainWindow &target);

	struct FilenameDescriptor {
		BTextControl *CsoundAbstractWindow::* /*const*/ pTextControl;
		const char *const pName;
		const char *const pLabel;
		bool mandatory;
		int32 whichFile;
		float width, height, divider;	
	};
	void CreateControls(FilenameDescriptor descriptors[],
								uint32 nItems,
								const CsoundAbstractMainWindow &target);

	struct NumberDescriptor {
		BTextControl *CsoundAbstractWindow::* /*const*/ pTextControl;
		const char *const pName;
		const char *const pLabel;
		const char *const pFormat;
		int32 whichNumber;
		float width, height, divider;	
	};
	void CreateControls(NumberDescriptor descriptors[],
								uint32 nItems,
								const CsoundAbstractMainWindow &target);

	const char *NumberToString(const char *pFormat, double value) const;
	double StringToNumber(const char *pFormat, const char *pString) const;
	
private:
	CsoundAbstractWindow(const CsoundAbstractWindow &);
	CsoundAbstractWindow &operator =(const CsoundAbstractWindow &);
	
	// Data members.
	BView *mpBackgroundView;
};

inline BView *
CsoundAbstractWindow::BackgroundView(void) const
{
	return mpBackgroundView;
}

#endif // CSABSTRACTWINDOW_H
