//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The heterodyne filter analysis window for Csound.

#ifndef CSHFMAINWINDOW_H
#define CSHFMAINWINDOW_H

#include <Button.h>
#include <Message.h>
#include <Point.h>
#include <TextControl.h>

#include "CsHFJob.h"
#include "CsAbstractMainWindow.h"
class CsoundTranscriptWindow;

class CsoundHFAnalysisMainWindow : public CsoundAbstractMainWindow
{
public:
	typedef CsoundAbstractMainWindow inherited;
	
	CsoundHFAnalysisMainWindow(
		BPoint origin, const char *pTitle,
		const CsoundHFAnalysisJob &job = CsoundHFAnalysisJob());
	virtual ~CsoundHFAnalysisMainWindow(void);

	// Hook functions.
	virtual void MessageReceived(BMessage *pMsg);

	// Message codes.
	enum {
		kStartAnalysis				= 'strt',	// commands
		kAbortAnalysis				= 'abrt'
	};

protected:
	// Hook functions.
	virtual void ValidJob(bool valid);
	
private:
	CsoundHFAnalysisMainWindow(const CsoundHFAnalysisMainWindow &);
	CsoundHFAnalysisMainWindow &operator =(const CsoundHFAnalysisMainWindow &);

	// Controls - file names.
	BTextControl *mpInputFilename;			// name of sound input file
	BTextControl *mpOutputFilename;			// name of analysis output file
	
	// Numeric parameters.
	BTextControl *mpSampleRate;				// -s ...
	BTextControl *mpChannel;					// -c ...
	BTextControl *mpBeginTime;					// -b ...
	BTextControl *mpDuration;					// -d ...
	BTextControl *mpBeginFrequency;			// -f ...
	BTextControl *mpNumPartials;				// -h ...
	BTextControl *mpMaxAmplitude;				// -M ...
	BTextControl *mpMinAmplitude;				// -m ...
	BTextControl *mpNumBreakpoints;			// -n ...
	BTextControl *mpLowPassFilter;			// -l ...
	
	// Actions.
	BButton *mpStart;								// start analysis
	BButton *mpAbort;								// abort analysis
	
	// Transcript window currently executing a job.
	CsoundTranscriptWindow *mpTranscriptWindow;
};

// Utiltity for control creation.
template <class Control>
 	inline Control *CsoundAbstractWindow::*const
	ptrCast(Control *CsoundHFAnalysisMainWindow::*const pControl)
	{
		return (Control *CsoundAbstractWindow::*const)pControl;
	}

#endif // CSHFMAINWINDOW_H
