//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The linear predictive analysis window for Csound.

#ifndef CSLPMAINWINDOW_H
#define CSLPMAINWINDOW_H

#include <Button.h>
#include <Message.h>
#include <Point.h>
#include <RadioButton.h>
#include <TextControl.h>

#include "CsLPJob.h"
#include "CsAbstractMainWindow.h"
class CsoundTranscriptWindow;

class CsoundLPAnalysisMainWindow : public CsoundAbstractMainWindow
{
public:
	typedef CsoundAbstractMainWindow inherited;
	
	CsoundLPAnalysisMainWindow(
		BPoint origin, const char *pTitle,
		const CsoundLPAnalysisJob &job = CsoundLPAnalysisJob());
	virtual ~CsoundLPAnalysisMainWindow(void);

	// Hook functions.
	virtual void MessageReceived(BMessage *pMsg);

	// Message codes.
	enum {
		kStartAnalysis				= 'strt',	// commands
		kAbortAnalysis				= 'abrt'
	};

protected:
	// Hook functions.
	virtual void ValidJob(bool valid);
	
private:
	CsoundLPAnalysisMainWindow(const CsoundLPAnalysisMainWindow &);
	CsoundLPAnalysisMainWindow &operator =(const CsoundLPAnalysisMainWindow &);

	// Controls - file names.
	BTextControl *mpInputFilename;			// name of sound input file
	BTextControl *mpOutputFilename;			// name of analysis output file
	BTextControl *mpCommentString;			// comment string (not a file)
	
	// Numeric parameters.
	BTextControl *mpSampleRate;				// -s ...
	BTextControl *mpChannel;					// -c ...
	BTextControl *mpBeginTime;					// -b ...
	BTextControl *mpDuration;					// -d ...
	BTextControl *mpNumPoles;					// -p ...
	BTextControl *mpHopSize;					// -h ...
	BTextControl *mpMinFrequency;				// -P ...
	BTextControl *mpMaxFrequency;				// -Q ...

	// Switches.
	BRadioButton *mpSilent;						// -v 0
	BRadioButton *mpVerbose;					// -v 1
	BRadioButton *mpDebug;						// -v 2
		
	// Actions.
	BButton *mpStart;								// start analysis
	BButton *mpAbort;								// abort analysis
	
	// Transcript window currently executing a job.
	CsoundTranscriptWindow *mpTranscriptWindow;
};

// Utiltity for control creation.
template <class Control>
 	inline Control *CsoundAbstractWindow::*const
	ptrCast(Control *CsoundLPAnalysisMainWindow::*const pControl)
	{
		return (Control *CsoundAbstractWindow::*const)pControl;
	}

#endif // CSLPMAINWINDOW_H
