//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		Application class for Csound.

#ifndef CSAPPLICATION_H
#define CSAPPLICATION_H

#include <Application.h>
#include <Bitmap.h>
#include <FilePanel.h>
#include <List.h>
#include <Message.h>
#include <Path.h>
#include <Window.h>

class CsoundEnvironmentJob;

class CsoundApplication : public BApplication {
public:
	typedef BApplication inherited;
	
	CsoundApplication(void);
	virtual ~CsoundApplication(void);

	// Message codes and fields.
	enum {
		kMainWindowCreated		= 'mwct',
		kMainWindowDestroyed		= 'mwdy',
		kOpenFile					= 'open',
		kShowEnvironment			= 'shnv'
	};
	static const char kFieldWindow[];

	// Hook functions.
	virtual void AboutRequested(void);
	virtual void MessageReceived(BMessage *pMsg);
	virtual bool QuitRequested(void);
	virtual void ReadyToRun(void);
	virtual void RefsReceived(BMessage *pMsg);

	// Get application icon, signature and directory.
	static BBitmap *GetIcon(void);
	static const char *GetSignature(void);
	static BPath GetDirectory(void);
	
	// Return a job describing environment variables.
	static const CsoundEnvironmentJob &EnvironmentJob(void);
	
	// Return list of prototype jobs.
	const BList &PrototypeJobs(void) const;
	
private:
	CsoundApplication(const CsoundApplication &);
	CsoundApplication &operator =(const CsoundApplication &);

	void SetEnvironment(const CsoundEnvironmentJob &job) const;
	static bool TryClosingWindow(void *pWin, void *pFlag);
	
	// Static data members.
	static BWindow *smpEnvironmentWindow;	// special environment var window
	static BFilePanel *smpFilePanel;		// application file panel

	// Data members.
	bool mWindowOpened;							// was a job opened during launch?
	BList mPrototypeJobs;						// prototypes of all concrete jobs
	BList mMainWindows;							// list of open main windows
};

inline const BList &
CsoundApplication::PrototypeJobs(void) const
{
	return mPrototypeJobs;
}

#endif // CSAPPLICATION_H
