//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The synthesis window for Csound.  Contains the most commonly needed
//		controls.

#ifndef CSSYNTHMAINWINDOW_H
#define CSSYNTHMAINWINDOW_H

#include <Button.h>
#include <CheckBox.h>
#include <Message.h>
#include <Point.h>
#include <TextControl.h>

#include "CsSynthJob.h"
#include "CsAbstractMainWindow.h"
class CsoundSynthesisOptionsWindow;
class CsoundTranscriptWindow;

class CsoundSynthesisMainWindow : public CsoundAbstractMainWindow
{
public:
	typedef CsoundAbstractMainWindow inherited;
	
	CsoundSynthesisMainWindow(
		BPoint origin, const char *pTitle,
		const CsoundSynthesisJob &job = CsoundSynthesisJob());
	virtual ~CsoundSynthesisMainWindow(void);

	// Hook functions.
	virtual void MessageReceived(BMessage *pMsg);

	// Message codes.
	enum {
		kStartSynthesis				= 'strt',	// commands
		kAbortSynthesis				= 'abrt'
	};

protected:
	// Hook functions.
	virtual void ValidJob(bool valid);
	virtual void AcceptDroppedRef(BPoint where, const entry_ref *pRef);
	
private:
	CsoundSynthesisMainWindow(const CsoundSynthesisMainWindow &);
	CsoundSynthesisMainWindow &operator =(const CsoundSynthesisMainWindow &);

	// Controls - file names.
	BTextControl *mpOrchestraFilename;		// name of orchestra file
	BTextControl *mpScoreFilename;			// name of score file
	BTextControl *mpExtractFilename;		// (optional) name of extract file
	BTextControl *mpInputFilename;			// (optional) name of sound input file
	BTextControl *mpLineFilename;				// (optional) name of line-oriented
														//            realtime input device
	BTextControl *mpMIDIFilename;				// (optional) name of MIDI file/device
	BTextControl *mpOutputFilename;			// (optional) name of sound output file
	BTextControl *mpTranscriptFilename;	// (optional) name of transcript file
	
	// On/off settings.
	BCheckBox *mpTranslateScore;				// -S (score is in SCOT format)
	BCheckBox *mpRealtimeMIDI;					// MIDI from file (-F) or device (-M)
	
	// Actions.
	BButton *mpStart;								// start synthesis
	BButton *mpAbort;								// abort synthesis
	
	// Transcript window currently executing a job.
	CsoundTranscriptWindow *mpTranscriptWindow;
};

// Utiltity for control creation.
template <class Control>
 	inline Control *CsoundAbstractWindow::*const
	ptrCast(Control *CsoundSynthesisMainWindow::*const pControl)
	{
		return (Control *CsoundAbstractWindow::*const)pControl;
	}

#endif // CSSYNTHMAINWINDOW_H
