//		Copyright © 1997	Jens Kilian
//
//		This program is free software; you can redistribute it and/or modify
//		it under the terms of the GNU General Public License as published by
//		the Free Software Foundation; either version 1, or (at your option)
//		any later version.
//
//		This program is distributed in the hope that it will be useful,
//		but WITHOUT ANY WARRANTY; without even the implied warranty of
//		MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
//		GNU General Public License for more details.
//
//		You should have received a copy of the GNU General Public License
//		along with this program; if not, write to the Free Software
//		Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

//		The synthesis options window; contains less frequently used settings.

#ifndef CSSYNTHOPTIONSWINDOW_H
#define CSSYNTHOPTIONSWINDOW_H

#include <CheckBox.h>
#include <Point.h>
#include <RadioButton.h>

class CsoundSynthesisMainWindow;
#include "CsAbstractOptionsWindow.h"

class CsoundSynthesisOptionsWindow : public CsoundAbstractOptionsWindow
{
public:
	typedef CsoundAbstractOptionsWindow inherited;
	
	CsoundSynthesisOptionsWindow(
		BPoint origin, const char *pTitle, CsoundSynthesisMainWindow &target);
	virtual ~CsoundSynthesisOptionsWindow(void);

private:
	CsoundSynthesisOptionsWindow(const CsoundSynthesisOptionsWindow &);
	CsoundSynthesisOptionsWindow &
		operator =(const CsoundSynthesisOptionsWindow &);

	// Controls - on/off settings.
	BCheckBox *mpPreprocessScore;				// -C
	BCheckBox *mpInitTimeOnly;					// -I
	BCheckBox *mpInhibitOutput;				// -n
	BCheckBox *mpRewriteSoundfileHdr;		// -R
	BCheckBox *mpDeferSoundfileLoads;		// -D
	BCheckBox *mpVerboseTranslation;		// -v
	BCheckBox *mpNoteAmplitudeMsgs;			// -m ...
	BCheckBox *mpOutOfRangeMsgs;
	BCheckBox *mpWarningMsgs;
	BCheckBox *mpHeartbeat;						// -H
	BCheckBox *mpNotifyAtEndOfJob;			// -N
	BCheckBox *mpTerminateAtEndOfTrk;		// -T
	
	// Numeric parameters.
	BTextControl *mpSoftwareSampleFrames;	// -b ...
	BTextControl *mpHardwareSampleFrames;	// -B ...
	BTextControl *mpSampleRateOverride;	// -r ...
	BTextControl *mpControlRateOverride;	// -k ...
	BTextControl *mpTempo;						// -t ...
	BTextControl *mpSustainPedalThreshold;// -P ...

	// 1-of-N selections.
	BRadioButton *mpNoHeaderFormat;			// -h
	BRadioButton *mpSoundfileFormat;		// (none)
	BRadioButton *mpAIFFFormat;				// -A
	BRadioButton *mpWAVFormat;					// -W

	BRadioButton *mpSigned8BitSamples;		// -c
	BRadioButton *mpUnsigned8BitSamples;	// -8
	BRadioButton *mpALawSamples;				// -a
	BRadioButton *mpmuLawSamples;				// -u
	BRadioButton *mpSigned16BitSamples;	// -s
	BRadioButton *mpSigned32BitSamples;	// -l
	BRadioButton *mpFloatSamples;				// -f

	BRadioButton *mpSuppressDisplays;		// -d
	BRadioButton *mpASCIIDisplays;			// -g
	BRadioButton *mpPostScriptDisplays;	// -G
	BRadioButton *mpGraphicsDisplays;		// (none)
};

// Utiltity for control creation.
template <class Control>
 	inline Control *CsoundAbstractWindow::*const
	ptrCast(Control *CsoundSynthesisOptionsWindow::*const pControl)
	{
		return (Control *CsoundAbstractWindow::*const)pControl;
	}

#endif // CSSYNTHOPTIONSWINDOW_H
